<?php
/**
 * Created by PhpStorm.
 * User: robin
 * Date: 9/30/15
 * Time: 7:04 PM
 */

namespace Luticate\Auth\Business;

use Illuminate\Http\Request;
use Luticate\Auth\DBO\LuticatePermissions;
use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuController;
use Luticate\Utils\LuRoute;

class LuticateBusiness
{
    const TOKEN_HEADER = "X-Authorization";

    /**
     * @var LuticateUsersDbo
     */
    private static $_currentUser;

    public static function getCurrentUser()
    {
        return self::$_currentUser;
    }

    /**
     * @param $permissions string[]
     * @param $request Request
     * @return bool
     */
    public static function authFilter($permissions, $request)
    {
        /**
         * @var $user LuticateUsersDbo
         */
        $user = null;
        $token = $request->header(self::TOKEN_HEADER);
        if ($token != null && $token != "") {
            $data = JwtHelper::decode($token);
            if ($data != null) {
                $user_id = $data[LuticateUsersBusiness::KEY_USER_ID];
                $salt = $data[LuticateUsersBusiness::KEY_SALT];
                $user = LuticateUsersBusiness::getById($user_id);
                if ($user->getSalt() != $salt) {
                    $user = null;
                }
            }
        }
        if (is_null($user)) {
            $user = LuticateUsersBusiness::getById(0);
        }

        self::$_currentUser = $user;
        LuController::$parameters["user"] = $user;

        $permissions[] = LuticatePermissions::USER_LOGIN;
        foreach ($permissions as $permission) {
            if (!LuticatePermissionsBusiness::getUserPermission(self::$_currentUser->getId(), $permission)) {
                return false;
            }
        }
        return true;
    }

    /**
     * @param $route LuRoute
     */
    public static function setupAuth($route)
    {
        $route->setMiddleware(function($permissions, $request)
        {
            return self::authFilter($permissions, $request);
        });
    }

    /**
     * @param $route LuRoute
     */
    public static function setupRoutes($route)
    {
        $prefix = "/luticate";
        $ns = 'Luticate\Auth\Business\\';
        $route->post("$prefix/login", "${ns}LuticateUsersBusiness", "login");
        $route->put("$prefix/logout", "${ns}LuticateUsersBusiness", "logout");
        $route->post("$prefix/add", "${ns}LuticateUsersBusiness", "add", LuticatePermissions::USER_ADD);
    }
}